a.open-file {
    color: #000;
    font-weight: bold;
    text-decoration: none;
}
a.open-file:hover{
    text-decoration: underline;
}
a.delete-anchor, a.crop{
    color: #08c;	
}
a.crop{
    margin-left: 10px;
}
.image-thumbnail img{
    cursor: -moz-zoom-in;
    cursor: -webkit-zoom-in;
}
.form-field-box.even .image-thumbnail img{
    border: 4px solid #fff;
}
.form-field-box.odd .image-thumbnail img{
    border: 4px solid #ddd;
}
